environ = {
    "ALLUSERSPROFILE": "C:\\ProgramData",
    "APPDATA": "C:\\Users\\rares\\AppData\\Roaming",
    "APPLICATION_INSIGHTS_NO_DIAGNOSTIC_CHANNEL": "true",
    "CHOCOLATEYINSTALL": "C:\\ProgramData\\chocolatey",
    "CHOCOLATEYLASTPATHUPDATE": "132163243699782294",
    "COMMONPROGRAMFILES": "C:\\Program Files\\Common Files",
    "COMMONPROGRAMFILES(X86)": "C:\\Program Files (x86)\\Common Files",
    "COMMONPROGRAMW6432": "C:\\Program Files\\Common Files",
    "COMPUTERNAME": "DESKTOP-2ML4R58",
    "COMSPEC": "C:\\WINDOWS\\system32\\cmd.exe",
    "DART_SDK": "C:\\Program Files\\Dart\\dart-sdk",
    "DRIVERDATA": "C:\\Windows\\System32\\Drivers\\DriverData",
    "FPS_BROWSER_APP_PROFILE_STRING": "Internet Explorer",
    "FPS_BROWSER_USER_PROFILE_STRING": "Default",
    "HOMEDRIVE": "C:",
    "HOMEPATH": "\\Users\\rares",
    "LOCALAPPDATA": "C:\\Users\\rares\\AppData\\Local",
    "LOGONSERVER": "\\\\DESKTOP-2ML4R58",
    "NUMBER_OF_PROCESSORS": "8",
    "ONEDRIVE": "C:\\Users\\rares\\OneDrive",
    "OS": "Windows_NT",
    "PATH": "C:\\WINDOWS\\system32;C:\\WINDOWS;C:\\WINDOWS\\System32\\Wbem;C:\\WINDOWS\\System32\\WindowsPowerShell\\v1.0\\;C:\\WINDOWS\\System32\\OpenSSH\\;C:\\Program Files\\Microsoft VS Code\\bin;C:\\Program Files\\Git\\cmd;C:\\Program Files (x86)\\ATI Technologies\\ATI.ACE\\Core-Static;C:\\Program Files\\nodejs\\;C:\\ProgramData\\chocolatey\\bin;C:\\WINDOWS\\system32\\config\\systemprofile\\.dnx\\bin;C:\\Program Files\\Microsoft DNX\\Dnvm\\;C:\\Program Files\\dotnet\\;C:\\Program Files\\Microsoft SQL Server\\130\\Tools\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\Client SDK\\ODBC\\170\\Tools\\Binn\\;C:\\Program Fules;C:\\WINDOWS\\system32\\WindowsPowerShell\\v1.0\\Modules",
    "PUBLIC": "C:\\Users\\Public",
    "SESSIONNAME": "Console",
    "SYSTEMDRIVE": "C:",
    "SYSTEMROOT": "C:\\WINDOWS",
    "TEMP": "C:\\Users\\rares\\AppData\\Local\\Temp",
    "TMP": "C:\\Users\\rares\\AppData\\Local\\Temp",
    "USERDOMAIN": "DESKTOP-2ML4R58",
    "USERDOMAIN_ROAMINGPROFILE": "DESKTOP-2ML4R58",
    "USERNAME": "rares",
    "USERPROFILE": "C:\\Users\\rares",
    "VBOX_MSI_INSTALL_PATH": "C:\\Program Files\\Oracle\\VirtualBox\\",
    "VS140COMNTOOLS": "C:\\Program Files (x86)\\Microsoft Visual Studio 14.0\\Common7\\Tools\\",
    "WINDIR": "C:\\WINDOWS",
    "TERM_PROGRAM": "vscode",
    "TERM_PROGRAM_VERSION": "1.39.2",
    "LANG": "en_US.UTF-8",
    "COLORTERM": "truecolor",
    "SERVER_NAME": "DESKTOP-2ML4R58",
    "GATEWAY_INTERFACE": "CGI/1.1",
    "SERVER_PORT": "80",
    "REMOTE_HOST": "",
    "CONTENT_LENGTH": "",
    "SCRIPT_NAME": "",
    "SERVER_PROTOCOL": "HTTP/1.1",
    "SERVER_SOFTWARE": "WSGIServer/0.2",
    "REQUEST_METHOD": "GET",
    "PATH_INFO": "/",
    "QUERY_STRING": "",
    "REMOTE_ADDR": "127.0.0.1",
    "CONTENT_TYPE": "text/plain",
    "HTTP_HOST": "127.0.0.1",
    "HTTP_USER_AGENT": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:70.0) Gecko/20100101 Firefox/70.0",
    "HTTP_ACCEPT": "text/html,application/xhtml+xml,application/xml;q,0.9,*/*;q,0.8",
    "HTTP_ACCEPT_LANGUAGE": "en-US,en;q,0.5",
    "HTTP_ACCEPT_ENCODING": "gzip, deflate",
    "HTTP_CONNECTION": "keep-alive",
    "HTTP_UPGRADE_INSECURE_REQUESTS": "1",
    "HTTP_CACHE_CONTROL": "max-age,0"
}
def start_response(response_value, *args):
    return response_value, args
